function [rMIRR,k,d,Fx,Fy,Fz,beta,delta,FdistY,xHOLE,yHOLE,zHOLE] = parMIRRphysDIM(X,Y,Z)

%%%
%%% PARABOLIC MIRROR PHYSICAL DIMENSIONS
%%%
%%% parabolic mirror described by a paraboloid with vertex at
%%% (x,y,z)=(0,0,0). 
%%%
%%% z = k*(x^2+y^2) = k*r^2
%%%
%%% z: direction of light collimated by the mirror (paraboloid axis)
%%% y: direction of electron beam
%%% x: direction perpendicular to y-z
%%%
%%% x-y are the coordinates of the paraboloid emicircle section, thus also
%%% the ones for the CCD image
%%% 

% X = 18.7; % dimension of mirror section on x direction (mm)
% Y = 8.1; % dimension of mirror section on y direction (mm)
% Z = 9.7; % dimension of mirror section on z direction (mm)

%%% calculate radius of circular section of mirror
a = Y;
b = X/2;
c = sqrt(a^2 + b^2);
%%% (c^2*COS(alpha))^2 -2*b^2*COS(alpha) + b^2-a^2 = 0
COSalpha = (2*b^2-sqrt(4*b^4+4*c^2*(a^2-b^2)))/(2*c^2);
rMIRR  = b/sin(acos(COSalpha));

%%% Z+d = k*(rMIRR^2)
%%% d = k*((rMIRR-Y)^2)
k = Z/(rMIRR^2-(rMIRR-Y)^2);
d = k*((rMIRR-Y)^2);

%%% focus --> F = (0,0,1/4k) 
Fx = 0; % x-coord of the focus (mm)
Fy = 0; % y-coord of the focus (mm)
Fz = 1/(4*k); % z-coord of the focus (mm)

beta = (180./pi).*(pi/2 - atan((rMIRR)/(Z+d-Fz))); % forward angle
delta = (180./pi).*(pi/2 - atan((rMIRR-Y)/(Fz-d))); % backward angle

FdistY = rMIRR-Y; % vertical distance of focus from mirror

%%% position of hole in the mirror (0,yHOLE,Fz)
%%% 
%%% z = k*(x^2+y^2) ={x=0}= k*y^2 ==> yHOLE = sqrt(Fz/k) = 1/2k
xHOLE = 0; % mm
yHOLE = 1/(2*k); % mm
zHOLE = Fz; % mm